@@ -8,7 +8,7 @@ use Class::Interface;
 
 use strict;
 use warnings;
-use  Carp qw(carp croak confess);
+use  Carp qw(carp croak confess cluck);
 use Data::Dumper;
 use Try::Tiny;
 
@@ -64,6 +64,7 @@ sub query{
 	#$self->{log}->debug(Dumper $rs);
 	$self->_init_pos;
 	$self->_init if ( @{$self->{cols}} == 0);
+	#return value of set_row_pos : 0 no data 1 found one or more row
 	$self->set_row_pos($self->{row}->{pos});
 	# $self->{log}->debug("query : " . @$data[0]->noti ) if (scalar @$data > 0);
 =for comment
@@ -165,10 +166,14 @@ sub get_field{
 	#my $pos =  $self->{row}->{pos};
 	#my $row = $self->{rs}->find(@{$self->{data}[$pos]});
 	my $row = $self->{current_row};
-	confess ("row undef") unless (defined $row);
-	my $value  = $row->get_column($id);
-	$self->{log}->debug("get_field " . $id . " value: " . (defined $value ? $value: "undef")); #fields : " . join(" ", $self->get_field_names) );
-	return $value; # or die(__PACKAGE__ . " no method found to get value from the column " . $id);;
+	my $value;
+	if (! defined  $row) {
+		 $self->{log}->debug("current row undef because there's no row");
+	} else {
+		$value  = $row->get_column($id);
+	}
+	$self->{log}->debug("get_field " . $id . " value: " . (defined $value ? $value: "undef"));
+	return $value; 
 
 }
 
@@ -556,6 +561,7 @@ The fields selected with C<'+columns'> or with C<'columns'> are readonly: a call
 =head2 C<query( $rs );>
 
 To display an other set of rows in a form, call the query method on the datamanager instance for this form with a new DBIx::Class::ResultSet object.
+Return 0 if there is no row or 1 if there are any rows found by the query.
 
 	my $rs = $self->{schema}->resultset('Books')->search_rs({no_title => $value});
 	$self->{form_a}->get_data_manager->query($rs);
