@@ -58,7 +58,7 @@ sub query{
 			$self->{log}->debug( $f . " : " . ($r->{$f} ? $r->{$f} : ""));
 		}
 	}
-
+	return (defined $self->{row}->{last_row} ? 1 : 0);
 
 } 
 
@@ -474,6 +474,7 @@ The fields selected with C<'+columns'> or with C<'columns'> are readonly: a call
 =head2 C<query( $data );>
 
 To display an other set of rows in a form, call the query method on the datamanager instance for this form with a new array of Rose::DB::Object derived objects.
+Return 0 if there is no row or 1 on if there are any.
 
 	my $data =  Rdb::Mytable::Manager->get_mytable(query => [pk_field => {eq => $value}]);
 	$self->{form_a}->get_data_manager->query($data);
